@@ -272,22 +272,22 @@ def create_item_runner(  # noqa
             container.fgVocabulary = data.get("fgVocabulary", [])
             continue
 
+        create_object = False
         if container.get(id_, False):
             # We check if the object is already created, if so we edit it
             obj = container[id_]
-            create_object = False
         else:
             # if don't we create it
             try:
                 obj = create(container, type_, id_=id_, title=title)
+                create_object = True
             except:  # noqa
-                logger.warn(
+                print_error(
                     "Can not create object {} ({}) in {}".format(
                         id_, type_, "/".join(container.getPhysicalPath())
                     )
                 )
-            create_object = True
-
+                continue
         try:
             # Acquisition wrap temporarily to satisfy things like vocabularies
             # depending on tools
@@ -299,7 +299,7 @@ def create_item_runner(  # noqa
             deserializer = queryMultiAdapter((obj, request), IDeserializeFromJson)
 
             if deserializer is None:
-                logger.warn("Cannot deserialize type {}".format(obj.portal_type))
+                print_error("Cannot deserialize type {}".format(obj.portal_type))
                 continue
 
             # defaults
@@ -504,8 +504,13 @@ def create_item_runner(  # noqa
                     notify(ObjectCreatedEvent(obj))
 
                 obj = add(container, obj, rename=not bool(id_))
+                obj_path = "/".join(obj.getPhysicalPath())
                 for image_fieldname in image_fieldnames_added:
-                    print_info("Generating image scales for {}".format(image_fieldname))
+                    print_info(
+                        "Generating image scales for {} field in {}".format(
+                            image_fieldname, obj_path
+                        )
+                    )
                     plone_scale_generate_on_save(obj, request, image_fieldname)
 
             # Set UUID - TODO: add to p.restapi
@@ -580,7 +585,7 @@ def create_item_runner(  # noqa
         except Exception as e:
             container_path = "/".join(container.getPhysicalPath())
             message = 'Could not edit the fields and properties for (type: "{0}", container: "{1}", id: "{2}", title: "{3}") exception: {4}'
-            logger.error(message.format(type_, container_path, id_, title, e))
+            print_error(message.format(type_, container_path, id_, title, e))
             continue
 
         # Call recursively
@@ -676,6 +681,10 @@ def content_creator_from_folder(
             print_info("Site root info found, applying changes")
             root_info = load_json(os.path.join(folder, "siteroot.json"))
             modify_siteroot(root_info)
+            continue
+        # blacklist "images" folder
+        elif file_ == "images":
+            continue
 
         # ex.: file_ = 'de.ueber-uns.json'
         filepath = os.path.join(folder, file_)
